NAME = "blue_geo"

ICON = "🌐"

DESCRIPTION = f"{ICON} AI for precise geospatial data analysis and visualization."

VERSION = "4.21.1"

REPO_NAME = "blue-geo"

MARQUEE = (
    "https://github.com/kamangir/assets/raw/main/nbs/ukraine-timemap/QGIS.png?raw=true"
)
